@@ -6,6 +6,11 @@ class NotLoggedInOortCloudError(OortCloudError):
         super().__init__('You must login first: `arcsecond login`')
 
 
+class InvalidWatchOptionsOortCloudError(OortCloudError):
+    def __init__(self, msg=''):
+        super().__init__(f'Invalid or incomplete Watch options: {msg}')
+
+
 class UnknownOrganisationOortCloudError(OortCloudError):
     def __init__(self, subdomain, error_string):
         msg = f'Invalid / unknown organisation with subdomain {subdomain}: {error_string}'
@@ -19,8 +24,10 @@ class UnknownTelescopeOortCloudError(OortCloudError):
 
 
 class InvalidAstronomerOortCloudError(OortCloudError):
-    def __init__(self, username, api_key):
-        msg = f'Invalid / unknown astronomer with username {username} (for the provided api_key {api_key}). '
+    def __init__(self, username, api_key=None):
+        msg = f'Invalid / unknown astronomer with username "{username}"'
+        if api_key:
+            msg += f' (for the provided api_key "{api_key}")'
         super().__init__(msg)
 
 
@@ -34,3 +41,9 @@ class InvalidOrganisationTelescopeOortCloudError(OortCloudError):
     def __init__(self, telescope_uuid):
         msg = f'Invalid / unknown telescope with UUID {telescope_uuid}.'
         super().__init__(msg)
+
+
+class InvalidOrganisationUploadKeyOortCloudError(OortCloudError):
+    def __init__(self, subdomain, username, api_key):
+        msg = f'Invalid / unknown upload key {api_key} for @{username} and {subdomain} organisation.'
+        super().__init__(msg)
